@@ -1,6 +1,10 @@
 #ifndef R2_CONFIGURE_H
 #define R2_CONFIGURE_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "r_version.h"
 
 #define R_CHECKS_LEVEL 2
@@ -10,26 +14,38 @@
 #define HAVE_EXPLICIT_BZERO 1
 #define HAVE_EXPLICIT_MEMSET 0
 #define HAVE_CLOCK_NANOSLEEP 1
+#define HAVE_SIGACTION 1
+#define WANT_THREADS 0
+#define WANT_CAPSTONE 1
+
+#define HAVE_GPERF 0
+#if (HAVE_GPERF) == 1
+#define HAVE_GPERF 0
+#else
+#define HAVE_GPERF 0
+#endif
 
 #ifdef R_MESON_VERSION
 #define R2_PREFIX "/usr"
+#define R2_ETCDIR "/usr/etc"
 #define R2_LIBDIR "/usr/lib"
 #define R2_INCDIR "/usr/include/libr"
 #define R2_DATDIR "/usr/share"
-#define R2_WWWROOT "/usr/share/radare2/4.0.0/www"
-#define R2_PLUGINS "lib/radare2/4.0.0"
-#define R2_EXTRAS "lib/radare2-extras/4.0.0"
-#define R2_BINDINGS "lib/radare2-bindings/4.0.0"
+#define R2_WWWROOT "/usr/share/radare2/5.7.8/www"
+#define R2_PLUGINS "lib/radare2/5.7.8"
+#define R2_EXTRAS "lib/radare2-extras/5.7.8"
+#define R2_BINDINGS "lib/radare2-bindings/5.7.8"
 #define R2_DATDIR_R2 "share/radare2"
-#define R2_SDB "share/radare2/4.0.0"
-#define R2_ZIGNS "share/radare2/4.0.0/zigns"
-#define R2_THEMES "share/radare2/4.0.0/cons"
-#define R2_FORTUNES "share/doc/radare2"
-#define R2_FLAGS "share/radare2/4.0.0/flag"
-#define R2_HUD "share/radare2/4.0.0/hud"
+#define R2_SDB "share/radare2/5.7.8"
+#define R2_ZIGNS "share/radare2/5.7.8/zigns"
+#define R2_THEMES "share/radare2/5.7.8/cons"
+#define R2_FORTUNES R_JOIN_3_PATHS ("/usr/share", "doc", "radare2")
+#define R2_FLAGS "share/radare2/5.7.8/flag"
+#define R2_HUD "share/radare2/5.7.8/hud"
 #else
 #if __WINDOWS__ || _MSC_VER
 #define R2_PREFIX "."
+#define R2_ETCDIR "etc"
 #define R2_LIBDIR "lib"
 #define R2_INCDIR "include\\libr"
 #define R2_DATDIR "share"
@@ -39,6 +55,7 @@
 #define R2_BINDINGS "lib\\bindings"
 #else
 #define R2_PREFIX "/usr"
+#define R2_ETCDIR "/usr/etc"
 #define R2_LIBDIR "/usr/lib"
 #define R2_INCDIR "/usr/include/libr/libr"
 #define R2_DATDIR "/usr/share"
@@ -66,11 +83,13 @@
 #define R2_HOME_CACHEDIR    R_JOIN_2_PATHS (".cache", "radare2")
 
 #define R2_HOME_THEMES      R_JOIN_2_PATHS (R2_HOME_DATADIR, "cons")
+#define R2_HOME_FORTUNES    R_JOIN_2_PATHS (R2_HOME_DATADIR, "fortunes")
 #define R2_HOME_PLUGINS     R_JOIN_2_PATHS (R2_HOME_DATADIR, "plugins")
 #define R2_HOME_ZIGNS       R_JOIN_2_PATHS (R2_HOME_DATADIR, "zigns")
 #define R2_HOME_PDB         R_JOIN_2_PATHS (R2_HOME_DATADIR, "pdb")
 #define R2_HOME_PROJECTS    R_JOIN_2_PATHS (R2_HOME_DATADIR, "projects")
 #define R2_HOME_WWWROOT     R_JOIN_2_PATHS (R2_HOME_DATADIR, "www")
+#define R2_HOME_SDB_FCNSIGN R_JOIN_2_PATHS (R2_HOME_DATADIR, "fcnsign")
 #define R2_HOME_SDB_FORMAT  R_JOIN_2_PATHS (R2_HOME_DATADIR, "format")
 #define R2_HOME_HUD         R_JOIN_2_PATHS (R2_HOME_DATADIR, "hud")
 #define R2_HOME_BINRC       R_JOIN_2_PATHS (R2_HOME_DATADIR, "rc.d")
@@ -88,15 +107,20 @@
 #define USE_LIB_XXHASH 1
 
 #ifndef HAVE_LIB_SSL
-#define HAVE_LIB_SSL 1
+#define HAVE_LIB_SSL 0
 #endif
 
 #define HAVE_LIBUV 1
 
+#if __MINGW32__
+#define HAVE_PTRACE 0
+#else
 #define HAVE_PTRACE 1
+#endif
+
 #define USE_PTRACE_WRAP 1
 #define HAVE_FORK 1
-
+#define WANT_DYLINK 1
 #define WITH_GPL 1
 
 #if __APPLE__ && __POWERPC__
@@ -105,4 +129,8 @@
 #define HAVE_JEMALLOC 1
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
