@@ -4,7 +4,8 @@
 #include <wchar.h>
 #include <stdarg.h>
 #include "r_str_util.h"
-#include "r_list.h"
+#include <r_list.h>
+#include <r_types_base.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -22,6 +23,10 @@ typedef enum {
 
 typedef int (*RStrRangeCallback) (void *, int);
 
+#define r_strf_buffer(s) char strbuf[s]
+#define r_strf_var(n,s, f, ...) char n[s]; snprintf (n, s, f, __VA_ARGS__);
+#define r_strf(s,...) (snprintf (strbuf, sizeof (strbuf), s, __VA_ARGS__)?strbuf: strbuf)
+
 typedef struct r_charset_rune_t {
 	ut8 *ch;
 	ut8 *hx;
@@ -41,7 +46,7 @@ typedef struct r_charset_t {
 #define R_STR_ISEMPTY(x) (!(x) || !*(x))
 #define R_STR_ISNOTEMPTY(x) ((x) && *(x))
 #define R_STR_DUP(x) ((x) ? strdup ((x)) : NULL)
-#define r_str_array(x,y) ((y>=0 && y<(sizeof(x)/sizeof(*x)))?x[y]:"")
+#define r_str_array(x,y) ((y>=0 && y<(sizeof (x)/sizeof (*x)))?x[y]:"")
 R_API RCharset *r_charset_new(void);
 R_API void r_charset_free(RCharset *charset);
 R_API RCharsetRune *r_charset_rune_new(const ut8 *ch, const ut8 *hx);
@@ -52,7 +57,7 @@ R_API bool r_charset_open(RCharset *c, const char *cs);
 R_API bool r_charset_use(RCharset *c, const char *cf);
 R_API RList *r_charset_list(RCharset *c);
 R_API void r_charset_close(RCharset *c);
-R_API RCharsetRune * add_rune(RCharsetRune *rcsr, const ut8 *ch, const ut8 *hx);
+R_API RCharsetRune *add_rune(RCharsetRune *rcsr, const ut8 *ch, const ut8 *hx);
 R_API RCharsetRune *search_from_hex(RCharsetRune *rcsr, const ut8 *hx);
 R_API RCharsetRune *search_from_char(RCharsetRune *rcsr, const ut8 *ch);
 
@@ -60,10 +65,12 @@ R_API RCharsetRune *search_from_char(RCharsetRune *rcsr, const ut8 *ch);
 R_API char *r_str_repeat(const char *ch, int sz);
 R_API const char *r_str_pad(const char ch, int len);
 R_API const char *r_str_rstr(const char *base, const char *p);
-R_API const char *r_strstr_ansi (const char *a, const char *b);
+R_API const char *r_strstr_ansi(const char *a, const char *b);
 R_API const char *r_str_rchr(const char *base, const char *p, int ch);
 R_API const char *r_str_closer_chr(const char *b, const char *s);
 R_API int r_str_bounds(const char *str, int *h);
+R_API R_WIP bool r_str_eq(const char *s1, const char *s2);
+R_API R_WIP bool r_str_eqi(const char *s1, const char *s2);
 R_API char *r_str_crop(const char *str, unsigned int x, unsigned int y, unsigned int x2, unsigned int y2);
 R_API char *r_str_scale(const char *r, int w, int h);
 R_API bool r_str_range_in(const char *r, ut64 addr);
@@ -89,9 +96,11 @@ R_API int r_str_split(char *str, char ch);
 R_API RList *r_str_split_list(char *str, const char *c, int n);
 R_API RList *r_str_split_duplist(const char *str, const char *c, bool trim);
 R_API size_t *r_str_split_lines(char *str, size_t *count);
-R_API char* r_str_replace(char *str, const char *key, const char *val, int g);
-R_API char *r_str_replace_icase(char *str, const char *key, const char *val, int g, int keep_case);
+R_API R_MUSTUSE char* r_str_replace(char *str, const char *key, const char *val, int g);
+R_API R_MUSTUSE char *r_str_replace_icase(char *str, const char *key, const char *val, int g, int keep_case);
 R_API char *r_str_replace_in(char *str, ut32 sz, const char *key, const char *val, int g);
+R_API R_MUSTUSE char* r_str_replace_thunked(char *str, char *clean, int *thunk, int clen, const char *key, const char *val, int g);
+R_API R_MUSTUSE char* r_str_replace_thunked(char *str, char *clean, int *thunk, int clen, const char *key, const char *val, int g);
 #define r_str_cpy(x,y) memmove ((x), (y), strlen (y) + 1);
 #define r_str_cat(x,y) memmove ((x) + strlen (x), (y), strlen (y) + 1);
 R_API int r_str_bits(char *strout, const ut8 *buf, int len, const char *bitz);
@@ -109,7 +118,7 @@ R_API int r_str_arg_unescape(char *arg);
 R_API char **r_str_argv(const char *str, int *_argc);
 R_API void r_str_argv_free(char **argv);
 R_API char *r_str_new(const char *str);
-R_API int r_snprintf (char *string, int len, const char *fmt, ...) R_PRINTF_CHECK(3, 4);
+R_API int r_snprintf(char *string, int len, const char *fmt, ...) R_PRINTF_CHECK(3, 4);
 R_API bool r_str_is_ascii(const char *str);
 R_API char *r_str_nextword(char *s, char ch);
 R_API bool r_str_is_printable(const char *str);
@@ -158,7 +167,7 @@ R_API const char *r_sub_str_rchr(const char *str, int start, int end, char chr);
 R_API char *r_str_ichr(char *str, char chr);
 R_API bool r_str_ccmp(const char *dst, const char *orig, int ch);
 R_API bool r_str_cmp_list(const char *list, const char *item, char sep);
-R_API int r_str_cmp(const char *dst, const char *orig, int len);
+R_API R_DEPRECATE int r_str_cmp(const char *dst, const char *orig, int len);
 R_API int r_str_casecmp(const char *dst, const char *orig);
 R_API int r_str_ncasecmp(const char *dst, const char *orig, size_t n);
 R_API int r_str_ccpy(char *dst, char *orig, int ch);
@@ -170,7 +179,7 @@ R_API char *r_str_dup(char *ptr, const char *string);
 R_API int r_str_inject(char *begin, char *end, char *str, int maxlen);
 R_API int r_str_delta(char *p, char a, char b);
 R_API void r_str_filter(char *str, int len);
-R_API const char * r_str_tok(const char *str1, const char b, size_t len);
+R_API const char *r_str_tok(const char *str1, const char b, size_t len);
 R_API wchar_t *r_str_mb_to_wc(const char *buf);
 R_API char *r_str_wc_to_mb(const wchar_t *buf);
 R_API wchar_t *r_str_mb_to_wc_l(const char *buf, int len);
@@ -188,6 +197,7 @@ R_API int r_str_path_unescape(char *path);
 R_API char *r_str_path_escape(const char *path);
 R_API int r_str_unescape(char *buf);
 R_API char *r_str_sanitize_r2(const char *buf);
+R_API char *r_str_escape_raw(const ut8 *buf, int sz);
 R_API char *r_str_escape(const char *buf);
 R_API char *r_str_escape_sh(const char *buf);
 R_API char *r_str_escape_sql(const char *buf);
@@ -209,8 +219,9 @@ R_API char *r_str_utf16_encode(const char *s, int len);
 R_API char *r_str_escape_utf8_for_json(const char *s, int len);
 R_API char *r_str_escape_utf8_for_json_strip(const char *buf, int buf_size);
 R_API char *r_str_encoded_json(const char *buf, int buf_size, int encoding);
-R_API char *r_str_home(const char *str);
-R_API char *r_str_r2_prefix(const char *str);
+R_API R_MUSTUSE char *r_str_home(const char *str); // R2_580 : rename to r_file_home() ?
+// R2_580: implement r_file_homef() for format string purposes
+R_API R_MUSTUSE char *r_str_r2_prefix(const char *str);
 R_API size_t r_str_nlen(const char *s, int n);
 R_API size_t r_str_nlen_w(const char *s, int n);
 R_API size_t r_wstr_clen(const char *s);
@@ -224,15 +235,30 @@ R_API void r_str_case(char *str, bool up);
 R_API void r_str_trim_path(char *s);
 R_API ut8 r_str_contains_macro(const char *input_value);
 R_API void r_str_truncate_cmd(char *string);
-R_API char* r_str_replace_thunked(char *str, char *clean, int *thunk, int clen,
-				  const char *key, const char *val, int g);
 R_API bool r_str_glob(const char *str, const char *glob);
 R_API int r_str_binstr2bin(const char *str, ut8 *out, int outlen);
 R_API char *r_str_between(const char *str, const char *prefix, const char *suffix);
+#undef r_str_startswith
 R_API bool r_str_startswith(const char *str, const char *needle);
+R_UNUSED static bool r_str_startswith_inline(const char *str, const char *needle) {
+	if (!str || !needle) {
+		return false;
+	}
+	if (str == needle) {
+		return true;
+	}
+	return !strncmp (str, needle, strlen (needle));
+}
+#define r_str_startswith r_str_startswith_inline
+R_UNUSED static const char *r_str_skip_prefix(const char *str, const char *prefix) {
+	if (r_str_startswith (str, prefix)) {
+		str += strlen (prefix);
+	}
+	return str;
+}
 R_API bool r_str_endswith(const char *str, const char *needle);
-R_API bool r_str_isnumber (const char *str);
-R_API const char *r_str_last (const char *in, const char *ch);
+R_API bool r_str_isnumber(const char *str);
+R_API const char *r_str_last(const char *in, const char *ch);
 R_API char* r_str_highlight(char *str, const char *word, const char *color, const char *color_reset);
 R_API char *r_qrcode_gen(const ut8 *text, int len, bool utf8, bool inverted);
 R_API char *r_str_from_ut64(ut64 val);
@@ -244,6 +270,7 @@ R_API const char *r_str_sep(const char *base, const char *sep);
 R_API const char *r_str_rsep(const char *base, const char *p, const char *sep);
 R_API char *r_str_donut(int size);
 R_API char *r_str_version(const char *program);
+R_API char *r_str_ss(const char* msg, const char *nl, int cs);
 
 #ifdef __cplusplus
 }
